==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/SwiadczenieRealizacjaKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class SwiadczenieRealizacjaKey extends GenericDPSObject {
    /**
     * SWIADCZENIE_REALIZACJA.SWIADCZENIE_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long swiadczenieId;

    /**
     * SWIADCZENIE_REALIZACJA.DATA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date data;

    /**
     * SWIADCZENIE_REALIZACJA.MIESZKANIEC_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long mieszkaniecId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SWIADCZENIE_REALIZACJA.SWIADCZENIE_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSwiadczenieId() {
        return swiadczenieId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * SWIADCZENIE_REALIZACJA.SWIADCZENIE_ID
     *
     * @param swiadczenieId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSwiadczenieId(Long swiadczenieId) {
        this.swiadczenieId = swiadczenieId;
    }

    /**
     * @return SWIADCZENIE_REALIZACJA.DATA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getData() {
        return data;
    }

    /**
     * SWIADCZENIE_REALIZACJA.DATA
     *
     * @param data
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return SWIADCZENIE_REALIZACJA.MIESZKANIEC_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getMieszkaniecId() {
        return mieszkaniecId;
    }

    /**
     * SWIADCZENIE_REALIZACJA.MIESZKANIEC_ID
     *
     * @param mieszkaniecId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setMieszkaniecId(Long mieszkaniecId) {
        this.mieszkaniecId = mieszkaniecId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        SwiadczenieRealizacjaKey other = (SwiadczenieRealizacjaKey) that;
        return (this.getSwiadczenieId() == null ? other.getSwiadczenieId() == null : this.getSwiadczenieId().equals(other.getSwiadczenieId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getMieszkaniecId() == null ? other.getMieszkaniecId() == null : this.getMieszkaniecId().equals(other.getMieszkaniecId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getSwiadczenieId() == null) ? 0 : getSwiadczenieId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getMieszkaniecId() == null) ? 0 : getMieszkaniecId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", swiadczenieId=").append(swiadczenieId);
        sb.append(", data=").append(data);
        sb.append(", mieszkaniecId=").append(mieszkaniecId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/SwiadczenieRealizacjaKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class SwiadczenieRealizacjaKey extends GenericDPSObject {
    /**
     * SWIADCZENIE_REALIZACJA.SWIADCZENIE_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long swiadczenieId;

    /**
     * SWIADCZENIE_REALIZACJA.DATA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date data;

    /**
     * SWIADCZENIE_REALIZACJA.MIESZKANIEC_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long mieszkaniecId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SWIADCZENIE_REALIZACJA.SWIADCZENIE_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSwiadczenieId() {
        return swiadczenieId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:47
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * SWIADCZENIE_REALIZACJA.SWIADCZENIE_ID
     *
     * @param swiadczenieId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSwiadczenieId(Long swiadczenieId) {
        this.swiadczenieId = swiadczenieId;
    }

    /**
     * @return SWIADCZENIE_REALIZACJA.DATA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getData() {
        return data;
    }

    /**
     * SWIADCZENIE_REALIZACJA.DATA
     *
     * @param data
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return SWIADCZENIE_REALIZACJA.MIESZKANIEC_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getMieszkaniecId() {
        return mieszkaniecId;
    }

    /**
     * SWIADCZENIE_REALIZACJA.MIESZKANIEC_ID
     *
     * @param mieszkaniecId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setMieszkaniecId(Long mieszkaniecId) {
        this.mieszkaniecId = mieszkaniecId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        SwiadczenieRealizacjaKey other = (SwiadczenieRealizacjaKey) that;
        return (this.getSwiadczenieId() == null ? other.getSwiadczenieId() == null : this.getSwiadczenieId().equals(other.getSwiadczenieId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getMieszkaniecId() == null ? other.getMieszkaniecId() == null : this.getMieszkaniecId().equals(other.getMieszkaniecId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getSwiadczenieId() == null) ? 0 : getSwiadczenieId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getMieszkaniecId() == null) ? 0 : getMieszkaniecId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", swiadczenieId=").append(swiadczenieId);
        sb.append(", data=").append(data);
        sb.append(", mieszkaniecId=").append(mieszkaniecId);
        sb.append("]");
        return sb.toString();
    }
}
